@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Point_set_processing_3/include/CGAL/IO/read_xyz_points.h $
-// $Id: read_xyz_points.h 10b0af3 2022-01-13T14:43:34+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Point_set_processing_3/include/CGAL/IO/read_xyz_points.h $
+// $Id: read_xyz_points.h 6555faf 2022-11-07T14:14:16+01:00 Jane Tournois
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Pierre Alliez and Laurent Saboret
@@ -90,8 +90,6 @@ bool read_XYZ(std::istream& is,
   typedef typename NP_helper::Normal_map NormalMap;
   typedef typename NP_helper::Geom_traits Kernel;
 
-  bool has_normals = NP_helper::has_normal_map();
-
   PointMap point_map = NP_helper::get_point_map(np);
   NormalMap normal_map = NP_helper::get_normal_map(np);
 
@@ -156,8 +154,7 @@ bool read_XYZ(std::istream& is,
         Enriched_point pwn;
         put(point_map,  pwn, point);  // point_map[pwn] = point
 
-        if (has_normals)
-          put(normal_map, pwn, normal); // normal_map[pwn] = normal
+        put(normal_map, pwn, normal); // normal_map[pwn] = normal
 
         *output++ = pwn;
         continue;
