@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Nef_3/include/CGAL/Nef_3/SNC_constructor.h $
-// $Id: SNC_constructor.h 43115e4 2021-05-05T21:57:47+01:00 Giles Bathgate
+// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Nef_3/include/CGAL/Nef_3/SNC_constructor.h $
+// $Id: SNC_constructor.h 2067913 2022-03-29T17:46:56+02:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -901,9 +901,8 @@ public:
     ++t2;
     if(t2 == segs2.end()) t2=segs2.begin();
 
-    SNC_intersection is;
     Point_3 ip;
-    bool flag=is.does_intersect_internally(Segment_3(*s1,*t1),Segment_3(*s2,*t2),ip);
+    bool flag = SNC_intersection::does_intersect_internally(Segment_3(*s1,*t1),Segment_3(*s2,*t2),ip);
     if(!flag) {
       if(*s1 == *s2) return normalized(*s1);
       else if(*s1 == *t2) return normalized(*s1);
@@ -2037,7 +2036,7 @@ class SNC_constructor<SNC_indexed_items, SNC_structure_>
         D.link_as_isolated_vertex(v2, f2);
         D.link_as_loop(l,f1);
         D.link_as_loop(l->twin(),f2);
-        l->circle() = Sphere_circle(faces_p->plane());
+        l->circle() = Sphere_circle(CGAL::ORIGIN,faces_p->plane());
         l->twin()->circle() = l->circle().opposite();
         f2->mark() = mf2;
         l->mark() = l->twin()->mark() = ml;
@@ -2053,7 +2052,7 @@ class SNC_constructor<SNC_indexed_items, SNC_structure_>
       SHalfedge_handle se1;
       SHalfedge_handle se2;
       SFace_handle sf;
-      Sphere_circle c(f->plane());
+      Sphere_circle c(CGAL::ORIGIN,f->plane());
 
       SHalfedge_handle next_edge;
       SHalfedge_around_svertex_const_circulator ec(E.out_edges(e)), ee(ec);
@@ -2104,7 +2103,7 @@ class SNC_constructor<SNC_indexed_items, SNC_structure_>
         se1 = D.new_shalfedge_pair(ec2->twin(), en->twin(), -1, 1);
         CGAL_NEF_TRACEN("new edge pair " << ec2->twin()->source()->vector() <<
                         " -> " << en->twin()->source()->vector());
-        se1->circle() = Sphere_circle(faces_p->plane());
+        se1->circle() = Sphere_circle(CGAL::ORIGIN,faces_p->plane());
         se1->twin()->circle() = se1->circle().opposite();
         se1->mark() = se1->twin()->mark() = BOP(mark_of_right_sface[ec2], faces_p->mark(), inv);
 
