@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Snapping/snap.h $
-// $Id: snap.h b92c22d 2021-09-28T16:49:19+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Snapping/snap.h $
+// $Id: snap.h 5a992f6 2022-11-22T10:31:34+01:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -14,7 +14,7 @@
 #ifndef CGAL_POLYGON_MESH_PROCESSING_SNAPPING_SNAP_H
 #define CGAL_POLYGON_MESH_PROCESSING_SNAPPING_SNAP_H
 
-#include <CGAL/license/Polygon_mesh_processing/repair.h>
+#include <CGAL/license/Polygon_mesh_processing/geometric_repair.h>
 
 #ifdef CGAL_PMP_SNAP_DEBUG_PP
  #ifndef CGAL_PMP_SNAP_DEBUG
@@ -25,7 +25,7 @@
 #include <CGAL/Polygon_mesh_processing/internal/Snapping/helper.h>
 #include <CGAL/Polygon_mesh_processing/internal/Snapping/snap_vertices.h>
 
-#include <CGAL/Polygon_mesh_processing/internal/named_function_params.h>
+#include <CGAL/Named_function_parameters.h>
 #include <CGAL/Polygon_mesh_processing/internal/named_params_helper.h>
 #include <CGAL/Polygon_mesh_processing/border.h>
 #include <CGAL/Polygon_mesh_processing/compute_normal.h>
@@ -151,13 +151,19 @@ void simplify_range(HalfedgeRange& halfedge_range,
             new_tolerance += CGAL::approximate_sqrt(CGAL::squared_distance(new_p, pt));
         }
 
+        if (!CGAL::Euler::does_satisfy_link_condition(edge(h, tm), tm))
+          continue;
+        const halfedge_descriptor opoh = opposite(prev(opposite(h, tm), tm), tm);
+        if (is_border(opoh, tm))
+          edges_to_test.erase( opoh );
         vertex_descriptor v = Euler::collapse_edge(edge(h, tm), tm);
+
         put(vpm, v, new_p);
         put(tolerance_map, v, new_tolerance);
 
         if(get(range_halfedges, prev_h))
           edges_to_test.insert(prev_h);
-        if(get(range_halfedges, next_h))
+        if(next_h!=opoh && get(range_halfedges, next_h))
           edges_to_test.insert(next_h);
 
         ++collapsed_n;
@@ -178,7 +184,7 @@ void simplify_range(HalfedgeRange& halfedge_range,
 
   halfedge_range = HalfedgeRange(new_range.begin(), new_range.end());
 
-  CGAL_postcondition(halfedge_range.size() == initial_n - collapsed_n);
+  CGAL_postcondition(halfedge_range.size() <= initial_n - collapsed_n);
 }
 
 // Adapted from <CGAL/AABB_tree/internal/AABB_traversal_traits.h>
@@ -764,15 +770,19 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
 
       if(is_visible)
       {
+        halfedge_descriptor h2 = prev(prev(h_to_split_opp, tm_T), tm_T);
         halfedge_descriptor new_hd = CGAL::Euler::split_face(h_to_split_opp,
-                                                             prev(prev(h_to_split_opp, tm_T), tm_T), tm_T);
+                                                             h2, tm_T);
         h_to_split = opposite(prev(new_hd, tm_T), tm_T);
+        visitor.after_split_face(h_to_split_opp, h2, tm_T);
       }
       else
       {
+        halfedge_descriptor h2 = prev(h_to_split_opp, tm_T);
         halfedge_descriptor new_hd = CGAL::Euler::split_face(opposite(res, tm_T),
-                                                             prev(h_to_split_opp, tm_T), tm_T);
+                                                             h2, tm_T);
         h_to_split = opposite(next(new_hd, tm_T), tm_T);
+        visitor.after_split_face(opposite(res, tm_T), h2, tm_T);
       }
     }
   }
@@ -1094,7 +1104,6 @@ std::size_t snap_non_conformal(HalfedgeRange& halfedge_range_A,
   >::reference                                                                    Visitor;
 
   using CGAL::parameters::choose_parameter;
-  using CGAL::parameters::is_default_parameter;
   using CGAL::parameters::get_parameter;
   using CGAL::parameters::get_parameter_reference;
 
@@ -1104,7 +1113,7 @@ std::size_t snap_non_conformal(HalfedgeRange& halfedge_range_A,
   const bool is_second_mesh_fixed = choose_parameter(get_parameter(np_B, internal_np::do_lock_mesh), false);
 
   internal::Snapping_default_visitor<TriangleMesh> default_visitor;
-  Visitor& visitor = choose_parameter(get_parameter_reference(np_A, internal_np::visitor), default_visitor);
+  Visitor visitor = choose_parameter(get_parameter_reference(np_A, internal_np::visitor), default_visitor);
 
   if(visitor.stop())
     return 0;
@@ -1291,13 +1300,16 @@ namespace experimental {
 template <typename ConcurrencyTag = CGAL::Sequential_tag,
           typename TriangleMesh,
           typename ToleranceMap_A, typename ToleranceMap_B,
-          typename NamedParameters_A, typename NamedParameters_B>
+          typename NamedParameters_A = parameters::Default_named_parameters,
+          typename NamedParameters_B = parameters::Default_named_parameters>
 std::size_t snap_borders(TriangleMesh& tm_A,
                          ToleranceMap_A tolerance_map_A,
                          TriangleMesh& tm_B,
                          ToleranceMap_B tolerance_map_B,
-                         const NamedParameters_A& np_A,
-                         const NamedParameters_B& np_B)
+                         const NamedParameters_A& np_A = parameters::default_values(),
+                         const NamedParameters_B& np_B = parameters::default_values(),
+                         const typename std::enable_if_t<!std::is_same<TriangleMesh, ToleranceMap_A>::value>* = 0 // Added to please MSVC 2015
+  )
 {
   typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor        halfedge_descriptor;
 
@@ -1313,11 +1325,12 @@ std::size_t snap_borders(TriangleMesh& tm_A,
 
 template <typename ConcurrencyTag = CGAL::Sequential_tag,
           typename TriangleMesh,
-          typename NamedParameters_A, typename NamedParameters_B>
+          typename NamedParameters_A = parameters::Default_named_parameters,
+          typename NamedParameters_B = parameters::Default_named_parameters>
 std::size_t snap_borders(TriangleMesh& tm_A,
                          TriangleMesh& tm_B,
-                         const NamedParameters_A& np_A,
-                         const NamedParameters_B& np_B)
+                         const NamedParameters_A& np_A = parameters::default_values(),
+                         const NamedParameters_B& np_B = parameters::default_values())
 {
   typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor        halfedge_descriptor;
 
@@ -1342,27 +1355,6 @@ std::size_t snap_borders(TriangleMesh& tm_A,
                                                       border_vertices_B, tm_B, tolerance_map_B,
                                                       false /*no self snapping*/, np_A, np_B);
 }
-
-template <typename ConcurrencyTag = CGAL::Sequential_tag,
-          typename TriangleMesh,
-          typename ToleranceMap_A, typename ToleranceMap_B>
-std::size_t snap_borders(TriangleMesh& tm_A,
-                         ToleranceMap_A tolerance_map_A,
-                         TriangleMesh& tm_B,
-                         ToleranceMap_B tolerance_map_B)
-{
-  return snap_borders<ConcurrencyTag>(tm_A, tolerance_map_A, tm_B, tolerance_map_B,
-                                      CGAL::parameters::all_default(), CGAL::parameters::all_default());
-}
-
-template <typename ConcurrencyTag = CGAL::Sequential_tag,
-          typename TriangleMesh>
-std::size_t snap_borders(TriangleMesh& tm_A,
-                         TriangleMesh& tm_B)
-{
-  return snap_borders<ConcurrencyTag>(tm_A, tm_B, CGAL::parameters::all_default(), CGAL::parameters::all_default());
-}
-
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1371,10 +1363,12 @@ std::size_t snap_borders(TriangleMesh& tm_A,
 template <typename ConcurrencyTag = CGAL::Sequential_tag,
           typename TriangleMesh,
           typename ToleranceMap,
-          typename CGAL_PMP_NP_TEMPLATE_PARAMETERS>
+          typename CGAL_NP_TEMPLATE_PARAMETERS>
 std::size_t snap_borders(TriangleMesh& tm,
                          ToleranceMap tolerance_map,
-                         const CGAL_PMP_NP_CLASS& np)
+                         const CGAL_NP_CLASS& np = parameters::default_values(),
+                         const typename std::enable_if_t<!std::is_same<TriangleMesh, ToleranceMap>::value>* = 0 // Added to please MSVC 2015
+)
 {
   typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor        halfedge_descriptor;
 
@@ -1388,18 +1382,9 @@ std::size_t snap_borders(TriangleMesh& tm,
 
 template <typename ConcurrencyTag = CGAL::Sequential_tag,
           typename TriangleMesh,
-          typename ToleranceMap>
+          typename CGAL_NP_TEMPLATE_PARAMETERS>
 std::size_t snap_borders(TriangleMesh& tm,
-                         ToleranceMap tolerance_map)
-{
-  return snap_borders<ConcurrencyTag>(tm, tolerance_map, CGAL::parameters::all_default());
-}
-
-template <typename ConcurrencyTag = CGAL::Sequential_tag,
-          typename TriangleMesh,
-          typename CGAL_PMP_NP_TEMPLATE_PARAMETERS>
-std::size_t snap_borders(TriangleMesh& tm,
-                         const CGAL_PMP_NP_CLASS& np)
+                         const CGAL_NP_CLASS& np = parameters::default_values())
 {
   typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor        halfedge_descriptor;
 
@@ -1421,13 +1406,6 @@ std::size_t snap_borders(TriangleMesh& tm,
                                                       true /*self snapping*/, np, np);
 }
 
-template <typename ConcurrencyTag = CGAL::Sequential_tag,
-          typename TriangleMesh>
-std::size_t snap_borders(TriangleMesh& tm)
-{
-  return snap_borders<ConcurrencyTag>(tm, CGAL::parameters::all_default());
-}
-
 } // end namespace experimental
 } // end namespace Polygon_mesh_processing
 } // end namespace CGAL
