@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Straight_skeleton_2/include/CGAL/Straight_skeleton_halfedge_base_2.h $
-// $Id: Straight_skeleton_halfedge_base_2.h b6333ed 2020-10-05T18:29:34+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Straight_skeleton_2/include/CGAL/Straight_skeleton_halfedge_base_2.h $
+// $Id: Straight_skeleton_halfedge_base_2.h 2410d8e 2023-01-04T16:36:34+01:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
@@ -62,8 +62,6 @@ public:
     return !this->vertex()->is_contour() && !this->opposite()->vertex()->is_contour();
   }
 
-  bool has_null_segment() const { return this->vertex()->has_null_point() ; }
-
   bool has_infinite_time() const { return this->vertex()->has_infinite_time() ; }
 
   Halfedge_const_handle defining_contour_edge() const { return this->face()->halfedge() ; }
