@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Surface_mesh_simplification/include/CGAL/Surface_mesh_simplification/internal/Edge_collapse.h $
-// $Id: Edge_collapse.h 9543deb 2021-10-29T17:40:15+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Surface_mesh_simplification/include/CGAL/Surface_mesh_simplification/internal/Edge_collapse.h $
+// $Id: Edge_collapse.h 45193b1 2022-03-10T10:50:06+05:30 G Yuvan Shankar
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando.cacciola@geometryfactory.com>
@@ -12,13 +12,14 @@
 #define CGAL_SURFACE_MESH_SIMPLIFICATION_DETAIL_EDGE_COLLAPSE_H
 
 #include <CGAL/license/Surface_mesh_simplification.h>
-
+#include <tuple>
 #include <CGAL/Surface_mesh_simplification/internal/Common.h>
 #include <CGAL/Surface_mesh_simplification/Policies/Edge_collapse/Edge_profile.h>
 
 #include <CGAL/boost/graph/Euler_operations.h>
 #include <CGAL/boost/graph/helpers.h>
 #include <CGAL/Modifiable_priority_queue.h>
+#include <CGAL/use.h>
 
 #include <boost/scoped_array.hpp>
 
@@ -89,7 +90,8 @@ template<class TM_,
          class GetCost_,
          class GetPlacement_,
          class ShouldIgnore_,
-         class VisitorT_>
+         class VisitorT_,
+         bool use_relaxed_heap>
 class EdgeCollapse
 {
   typedef EdgeCollapse                                                    Self;
@@ -173,28 +175,25 @@ public:
     const Self* m_algorithm;
   };
 
-  typedef Modifiable_priority_queue<halfedge_descriptor, Compare_cost, edge_id>     PQ;
-  typedef typename PQ::handle                                                       PQ_handle;
+  static const Heap_type hp = use_relaxed_heap ? CGAL_BOOST_PENDING_RELAXED_HEAP
+                                               : CGAL_BOOST_PENDING_MUTABLE_QUEUE;
+  typedef Modifiable_priority_queue<halfedge_descriptor, Compare_cost, edge_id, hp>     PQ;
 
   // An Edge_data is associated with EVERY _ edge in the mesh (collapsable or not).
-  // It relates the edge with the PQ-handle needed to update the priority queue
+  // It contains the edge status wrt the priority queue
   // It also relates the edge with a policy-based cache
-  class Edge_data
+  struct Edge_data
   {
-  public :
-    Edge_data() : m_PQ_h() {}
-
     const Cost_type& cost() const { return m_cost; }
     Cost_type& cost() { return m_cost; }
 
-    PQ_handle queue_handle() const { return m_PQ_h;}
-    bool is_in_PQ() const { return m_PQ_h != PQ::null_handle(); }
-    void set_PQ_handle(PQ_handle h) { m_PQ_h = h; }
-    void reset_queue_handle() { m_PQ_h = PQ::null_handle(); }
+    bool is_in_PQ() const { return m_is_in_PQ; }
+    void set_is_in_PQ() { m_is_in_PQ=true; }
+    void reset_in_queue_status() { m_is_in_PQ = false; }
 
   private:
     Cost_type m_cost;
-    PQ_handle m_PQ_h;
+    bool m_is_in_PQ = false;
   };
 
   typedef Edge_data*                                                                Edge_data_ptr;
@@ -266,12 +265,12 @@ private:
   typename boost::property_traits<Vertex_point_map>::reference
   get_point(const vertex_descriptor v) const { return get(m_vpm, v); }
 
-  boost::tuple<vertex_descriptor, vertex_descriptor> get_vertices(const halfedge_descriptor h) const
+  std::tuple<vertex_descriptor, vertex_descriptor> get_vertices(const halfedge_descriptor h) const
   {
     vertex_descriptor p, q;
     p = source(h, m_tm);
     q = target(h, m_tm);
-    return boost::make_tuple(p, q);
+    return std::make_tuple(p, q);
   }
 
   std::string vertex_to_string(const vertex_descriptor v) const
@@ -283,7 +282,7 @@ private:
   std::string edge_to_string(const halfedge_descriptor h) const
   {
     vertex_descriptor p, q;
-    boost::tie(p,q) = get_vertices(h);
+    std::tie(p,q) = get_vertices(h);
     return boost::str(boost::format("{E%1% %2%->%3%}%4%") % get_edge_id(h) % vertex_to_string(p) % vertex_to_string(q) % (is_border(h, m_tm) ? " (BORDER)" : (is_border(opposite(h, m_tm), m_tm) ? " (~BORDER)": "")));
   }
 
@@ -301,7 +300,8 @@ private:
     CGAL_expensive_assertion(!data.is_in_PQ());
     CGAL_expensive_assertion(!mPQ->contains(h));
 
-    data.set_PQ_handle(mPQ->push(h));
+    mPQ->push(h);
+    data.set_is_in_PQ();
 
     CGAL_expensive_assertion(data.is_in_PQ());
     CGAL_expensive_assertion(mPQ->contains(h));
@@ -312,8 +312,9 @@ private:
     CGAL_assertion(is_primary_edge(h));
     CGAL_expensive_assertion(data.is_in_PQ());
     CGAL_expensive_assertion(mPQ->contains(h));
+    CGAL_USE(data);
 
-    data.set_PQ_handle(mPQ->update(h, data.queue_handle()));
+    mPQ->update(h);
 
     CGAL_assertion(data.is_in_PQ());
     CGAL_expensive_assertion(mPQ->contains(h));
@@ -325,7 +326,8 @@ private:
     CGAL_expensive_assertion(data.is_in_PQ());
     CGAL_expensive_assertion(mPQ->contains(h));
 
-    data.set_PQ_handle(mPQ->erase(h, data.queue_handle()));
+    mPQ->erase(h);
+    data.reset_in_queue_status();
 
     CGAL_expensive_assertion(!data.is_in_PQ());
     CGAL_expensive_assertion(!mPQ->contains(h));
@@ -339,7 +341,7 @@ private:
       CGAL_assertion(is_primary_edge(*opt_h));
       CGAL_expensive_assertion(get_data(*opt_h).is_in_PQ());
 
-      get_data(*opt_h).reset_queue_handle();
+      get_data(*opt_h).reset_in_queue_status();
 
       CGAL_expensive_assertion(!get_data(*opt_h).is_in_PQ());
       CGAL_expensive_assertion(!mPQ->contains(*opt_h));
@@ -401,8 +403,8 @@ private:
   CGAL_SMS_DEBUG_CODE(unsigned m_step;)
 };
 
-  template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V>
-  EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 EdgeCollapse(Triangle_mesh& tmesh,
              const Geom_traits& traits,
              const Should_stop& should_stop,
@@ -443,9 +445,9 @@ EdgeCollapse(Triangle_mesh& tmesh,
 #endif
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 int
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 run()
 {
   CGAL_expensive_precondition(is_valid_polygon_mesh(m_tm) && CGAL::is_triangle_mesh(m_tm));
@@ -470,9 +472,9 @@ run()
   return r;
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 void
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 collect()
 {
   CGAL_SMS_TRACE(0, "collecting edges...");
@@ -579,9 +581,9 @@ collect()
   CGAL_SMS_TRACE(0, "Initial edge count: " << m_initial_edge_count);
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 void
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 loop()
 {
   CGAL_SMS_TRACE(0, "Collapsing edges...");
@@ -668,9 +670,9 @@ loop()
   }
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 bool
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 is_border_or_constrained(const vertex_descriptor v) const
 {
   for(halfedge_descriptor h : halfedges_around_target(v, m_tm))
@@ -682,9 +684,9 @@ is_border_or_constrained(const vertex_descriptor v) const
   return false;
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 bool
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 is_constrained(const vertex_descriptor v) const
 {
   for(halfedge_descriptor h : halfedges_around_target(v, m_tm))
@@ -703,9 +705,9 @@ is_constrained(const vertex_descriptor v) const
 // The link condition is as follows: for every vertex 'k' adjacent to both 'p and 'q',
 // "p,k,q" is a facet of the mesh.
 //
-  template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 bool
-  EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+  EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 is_collapse_topologically_valid(const Profile& profile)
 {
   bool res = true;
@@ -871,17 +873,17 @@ is_collapse_topologically_valid(const Profile& profile)
   return res;
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 bool
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 is_tetrahedron(const halfedge_descriptor h)
 {
   return CGAL::is_tetrahedron(h, m_tm);
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 bool
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 is_open_triangle(const halfedge_descriptor h1)
 {
   bool res = false;
@@ -910,9 +912,9 @@ is_open_triangle(const halfedge_descriptor h1)
 // respective areas is no greater than a max value and the internal
 // dihedral angle formed by their supporting planes is no greater than
 // a given threshold
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 bool
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 are_shared_triangles_valid(const Point& p0, const Point& p1, const Point& p2, const Point& p3) const
 {
   bool res = false;
@@ -962,9 +964,9 @@ are_shared_triangles_valid(const Point& p0, const Point& p1, const Point& p2, co
 }
 
 // Returns the directed halfedge connecting v0 to v1, if exists.
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
-typename EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::halfedge_descriptor
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
+typename EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::halfedge_descriptor
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 find_connection(const vertex_descriptor v0,
                 const vertex_descriptor v1) const
 {
@@ -979,9 +981,9 @@ find_connection(const vertex_descriptor v0,
 
 // Given the edge 'e' around the link for the collapsinge edge "v0-v1", finds the vertex that makes a triangle adjacent to 'e' but exterior to the link (i.e not containing v0 nor v1)
 // If 'e' is a null handle OR 'e' is a border edge, there is no such triangle and a null handle is returned.
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
-typename EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::vertex_descriptor
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
+typename EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::vertex_descriptor
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 find_exterior_link_triangle_3rd_vertex(const halfedge_descriptor e,
                                        const vertex_descriptor v0,
                                        const vertex_descriptor v1) const
@@ -1015,9 +1017,9 @@ find_exterior_link_triangle_3rd_vertex(const halfedge_descriptor e,
 // A collapse is geometrically valid if, in the resulting local mesh no two adjacent triangles form an internal dihedral angle
 // greater than a fixed threshold (i.e. triangles do not "fold" into each other)
 //
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 bool
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 is_collapse_geometrically_valid(const Profile& profile, Placement_type k0)
 {
   bool res = false;
@@ -1114,9 +1116,9 @@ is_collapse_geometrically_valid(const Profile& profile, Placement_type k0)
   return res;
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 void
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 collapse(const Profile& profile,
          Placement_type placement)
 {
@@ -1217,9 +1219,9 @@ collapse(const Profile& profile,
   CGAL_SMS_DEBUG_CODE(++m_step;)
 }
 
-template<class TM, class GT, class SP, class VIM, class VPM, class HIM, class ECM, class CF, class PF, class SI, class V>
+template<class TM, class GT, class SP, class VIM, class VPM,class HIM, class ECM, class CF, class PF, class SI, class V, bool URH>
 void
-EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V>::
+EdgeCollapse<TM,GT,SP,VIM,VPM,HIM,ECM,CF,PF,SI,V,URH>::
 update_neighbors(const vertex_descriptor v_kept)
 {
   CGAL_SMS_TRACE(3,"Updating cost of neighboring edges...");
