@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Tetrahedral_remeshing/include/CGAL/Tetrahedral_remeshing/internal/tetrahedral_remeshing_helpers.h $
-// $Id: tetrahedral_remeshing_helpers.h 1c1d5d1 2022-02-17T15:10:40+00:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Tetrahedral_remeshing/include/CGAL/Tetrahedral_remeshing/internal/tetrahedral_remeshing_helpers.h $
+// $Id: tetrahedral_remeshing_helpers.h 4b87443 2022-12-05T12:20:06+01:00 Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -441,7 +441,7 @@ bool is_boundary(const C3T3& c3t3,
                  const CellSelector& cell_selector)
 {
   return c3t3.is_in_complex(f)
-         || cell_selector(f.first) != cell_selector(f.first->neighbor(f.second));
+    || get(cell_selector, f.first) != get(cell_selector, f.first->neighbor(f.second));
 }
 
 template<typename C3T3, typename CellSelector>
@@ -497,7 +497,7 @@ bool is_boundary_vertex(const typename C3t3::Vertex_handle& v,
   {
     if (c3t3.is_in_complex(f))
       return true;
-    if (cell_selector(f.first) ^ cell_selector(f.first->neighbor(f.second)))
+    if (get(cell_selector, f.first) ^ get(cell_selector, f.first->neighbor(f.second)))
       return true;
   }
   return false;
@@ -767,7 +767,7 @@ bool is_outside(const typename C3t3::Edge & edge,
     if (c3t3.is_in_complex(circ))
       return false;
     // does circ belong to the selection?
-    if (cell_selector(circ))
+    if (get(cell_selector, circ))
       return false;
 
     ++circ;
@@ -789,7 +789,7 @@ bool is_selected(const typename C3t3::Vertex_handle v,
 
   for(Cell_handle c : cells)
   {
-    if (cell_selector(c))
+    if (get(cell_selector, c))
       return true;
   }
   return false;
@@ -814,7 +814,7 @@ bool is_internal(const typename C3t3::Edge& edge,
       return false;
     if (si != circ->subdomain_index())
       return false;
-    if (!cell_selector(circ))
+    if (!get(cell_selector, circ))
       return false;
     if (c3t3.is_in_complex(
           circ,
@@ -836,7 +836,7 @@ bool is_selected(const typename C3T3::Triangulation::Edge& e,
   Cell_circulator done = circ;
   do
   {
-    if (cell_selector(circ))
+    if (get(cell_selector, circ))
       return true;
   } while (++circ != done);
 
@@ -1135,6 +1135,38 @@ void get_edge_info(const typename C3t3::Edge& edge,
   }
 }
 
+namespace internal
+{
+  template<typename C3t3, typename CellSelector>
+  void treat_before_delete(typename C3t3::Cell_handle c,
+                           CellSelector& cell_selector,
+                           C3t3& c3t3)
+  {
+    if (c3t3.is_in_complex(c))
+      c3t3.remove_from_complex(c);
+    if (get(cell_selector, c))
+      put(cell_selector, c, false);
+  }
+
+  template<typename C3t3, typename CellSelector>
+  void treat_new_cell(typename C3t3::Cell_handle c,
+                      const typename C3t3::Subdomain_index& subdomain,
+                      CellSelector& cell_selector,
+                      const bool selected,
+                      C3t3& c3t3)
+  {
+    //update C3t3
+    using Subdomain_index = typename C3t3::Subdomain_index;
+    if (Subdomain_index() != subdomain)
+      c3t3.add_to_complex(c, subdomain);
+    else
+      c->set_subdomain_index(Subdomain_index());
+
+    //update cell_selector property map
+    put(cell_selector, c, selected);
+  }
+}
+
 namespace debug
 {
 
@@ -1592,11 +1624,9 @@ void dump_cells_with_small_dihedral_angle(const Tr& tr,
   std::vector<Cell_handle>     cells;
   std::vector<Subdomain_index> indices;
 
-  for (typename Tr::Finite_cells_iterator cit = tr.finite_cells_begin();
-       cit != tr.finite_cells_end(); ++cit)
+  for (Cell_handle c : tr.finite_cell_handles())
   {
-    Cell_handle c = cit;
-    if (c->subdomain_index() != Subdomain_index() && cell_select(c))
+    if (c->subdomain_index() != Subdomain_index() && get(cell_select, c))
     {
       double dh = min_dihedral_angle(tr, c);
       if (dh < angle_bound)
