@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Straight_skeleton_2/include/CGAL/constructions/Straight_skeleton_cons_ftC2.h $
-// $Id: Straight_skeleton_cons_ftC2.h 7d311d3 2020-11-27T13:54:22+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Straight_skeleton_2/include/CGAL/constructions/Straight_skeleton_cons_ftC2.h $
+// $Id: Straight_skeleton_cons_ftC2.h e2f1940 2023-01-04T16:17:15+01:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
@@ -45,7 +45,7 @@ bool are_parallel_edges_equally_oriented( Segment_2_with_ID<K> const& e0, Segmen
 template<class K>
 bool are_edges_orderly_collinear( Segment_2_with_ID<K> const& e0, Segment_2_with_ID<K> const& e1 )
 {
-  return are_edges_collinear(e0,e1) & are_parallel_edges_equally_oriented(e0,e1);
+  return are_edges_collinear(e0,e1) && are_parallel_edges_equally_oriented(e0,e1);
 }
 
 
@@ -385,10 +385,10 @@ boost::optional< Point_2<K> > compute_oriented_midpoint ( Segment_2_with_ID<K> c
 // If you ask for the right child point for a trisegment tree corresponding to a split event you will just get e1.target()
 // which is nonsensical for a non initial split event.
 //
-// NOTE: There is an abnormal collinearity case which ocurrs when e0 and e2 are collinear.
+// NOTE: There is an abnormal collinearity case which occurs when e0 and e2 are collinear.
 // In this case, these lines do not correspond to an offset vertex (because e0* and e2* are never consecutive before the event),
 // so the degenerate seed is neither the left or the right seed. In this case, the SEED ID for the degenerate pseudo seed is UNKOWN.
-// If you request the point of such degenerate pseudo seed the oriented midpoint bettwen e0 and e2 is returned.
+// If you request the point of such degenerate pseudo seed the oriented midpoint between e0 and e2 is returned.
 //
 template <class K, class CoeffCache>
 boost::optional< Point_2<K> >
