@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Mesh_3/include/CGAL/refine_mesh_3.h $
-// $Id: refine_mesh_3.h 3e03d50 2021-05-05T15:32:22+02:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Mesh_3/include/CGAL/refine_mesh_3.h $
+// $Id: refine_mesh_3.h 1c3e09f 2022-01-10T15:32:38+01:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -254,7 +254,7 @@ CGAL_IGNORE_BOOST_PARAMETER_NAME_WARNINGS
 // -----------------------------------
 BOOST_PARAMETER_FUNCTION((internal::Perturb_options), perturb, tag,
                          (optional (time_limit_, *, internal::undef_parameter )
-                                   (sliver_bound_, *, default_values::perturb_sliver_bound )))
+                                   (sliver_bound_, *, default_values_for_mesh_3::perturb_sliver_bound )))
 {
   internal::Perturb_options options(true);
 
@@ -273,7 +273,7 @@ inline internal::Perturb_options no_perturb() { return internal::Perturb_options
 // -----------------------------------
 BOOST_PARAMETER_FUNCTION((internal::Exude_options), exude, tag,
                          (optional (time_limit_, *, internal::undef_parameter )
-                                   (sliver_bound_, *, default_values::exude_sliver_bound )))
+                                   (sliver_bound_, *, default_values_for_mesh_3::exude_sliver_bound )))
 {
   internal::Exude_options options(true);
 
@@ -293,8 +293,8 @@ inline internal::Exude_options no_exude() { return internal::Exude_options(false
 BOOST_PARAMETER_FUNCTION((internal::Odt_options), odt, tag,
                          (optional (time_limit_, *, 0 )
                                    (max_iteration_number_, *, 0 )
-                                   (convergence_, *, default_values::odt_convergence_ratio )
-                                   (freeze_bound_, *, default_values::odt_freeze_ratio )))
+                                   (convergence_, *, default_values_for_mesh_3::odt_convergence_ratio )
+                                   (freeze_bound_, *, default_values_for_mesh_3::odt_freeze_ratio )))
 {
   internal::Odt_options options(true);
 
@@ -314,8 +314,8 @@ inline internal::Odt_options no_odt() { return internal::Odt_options(false); }
 BOOST_PARAMETER_FUNCTION((internal::Lloyd_options), lloyd, tag,
                          (optional (time_limit_, *, 0 )
                                    (max_iteration_number_, *, 0 )
-                                   (convergence_, *, default_values::lloyd_convergence_ratio )
-                                   (freeze_bound_, *, default_values::lloyd_freeze_ratio )))
+                                   (convergence_, *, default_values_for_mesh_3::lloyd_convergence_ratio )
+                                   (freeze_bound_, *, default_values_for_mesh_3::lloyd_freeze_ratio )))
 {
   internal::Lloyd_options options(true);
 
